.. _signal_analysis.lempel_ziv:

Lempel‑Ziv Complexity
=====================

.. automodule:: eyetrace.signal_analysis.lempel_ziv
   :members:
   :undoc-members:
   :show-inheritance:

Lempel‑Ziv complexity assesses the repetitiveness of a sequence by counting
the number of distinct patterns. It is often applied to binarized signals and
reflects the information content of the data.